==> mirai_dropdown_menu-0.0.6%2B3.tar.gz: example/lib/app/data/projects.dart <==
/*
* Created By Mirai Devs.
* On 24/6/2022.
*/

import 'package:example/app/models/project_model.dart';
import 'package:flutter/material.dart';

ProjectModel projectModel0 = ProjectModel(
  job: "UI / UX Design",
  name: "Mohammed Benmchich",
  title: "20% completed 19988 budget left",
  progress: 0.2,
  color: listColor[0],
);

ProjectModel projectModel1 = ProjectModel(
  job: "Product Design",
  name: "Mohammed Benmchich",
  title: "10% completed 19988 budget left",
  progress: 0.1,
  color: listColor[1],
);

ProjectModel projectModel2 = ProjectModel(
  job: "BackEnd Development",
  name: "Bilal Aboubi",
  title: "5% completed 19988 budget left",
  progress: 0.05,
  color: listColor[2],
);

ProjectModel projectModel3 = ProjectModel(
  job: "UI / UX",
  name: "Mohammed Benmchich",
  title: "60% completed 19988 budget left",
  progress: 0.6,
  color: listColor[3],
);

ProjectModel projectModel4 = ProjectModel(
  job: "Flutter Development",
  name: "Hamza Chaouki",
  title: "90% completed 19988 budget left",
  progress: 0.9,
  color: listColor[4],
);

ProjectModel projectModel5 = ProjectModel(
  job: "Flutter Development",
  name: "Hamza El Hirch",
  title: "100% completed 19988 budget left",
  progress: 1,
  color: listColor[5],
);

ProjectModel projectModel6 = ProjectModel(
  job: "Web Dev",
  name: "Bilal Aboubi",
  title: "15% completed 19988 budget left",
  progress: 0.5,
  color: listColor[6],
);

ProjectModel projectModel7 = ProjectModel(
  job: "Marketing",
  name: "Mohammed Benmchich",
  title: "34% completed 19988 budget left",
  progress: 0.34,
  color: listColor[0],
);

ProjectModel projectModel8 = ProjectModel(
  job: "Illustration",
  name: "Mohammed Benmchich",
  title: "66% completed 19988 budget left",
  progress: 0.66,
  color: listColor[1],
);

ProjectModel projectModel9 = ProjectModel(
  job: "Editing",
  name: "Mohammed Benmchich",
  title: "77% completed 19988 budget left",
  progress: 0.77,
  color: listColor[2],
);

List<ProjectModel> listProjects = [
  projectModel0,
  projectModel1,
  projectModel2,
  projectModel3,
  projectModel4,
  projectModel5,
  projectModel6,
  projectModel7,
  projectModel8,
  projectModel9,
];

const List<Color> listColor = [
  Color(0xFFF56287),
  Color(0xFF37B34A),
  Color(0xFF1488CC),
  Color(0xFFE0B719),
  Color(0xffB455FF),
  Color(0xff07BBC7),
  Color(0xffFF5A5A),
];

==> mirai_dropdown_menu-0.0.7%2B3.tar.gz: example/lib/app/data/projects.dart <==
/*
* Created By Mirai Devs.
* On 24/6/2022.
*/

import 'package:example/app/models/project_model.dart';
import 'package:flutter/material.dart';

ProjectModel projectModel0 = ProjectModel(
  job: "UI / UX Design",
  name: "Mohammed Benmchich",
  title: "20% completed 19988 budget left",
  progress: 0.2,
  color: listColor[0],
);

ProjectModel projectModel1 = ProjectModel(
  job: "Product Design",
  name: "Mohammed Benmchich",
  title: "10% completed 19988 budget left",
  progress: 0.1,
  color: listColor[1],
);

ProjectModel projectModel2 = ProjectModel(
  job: "BackEnd Development",
  name: "Bilal Aboubi",
  title: "5% completed 19988 budget left",
  progress: 0.05,
  color: listColor[2],
);

ProjectModel projectModel3 = ProjectModel(
  job: "UI / UX",
  name: "Mohammed Benmchich",
  title: "60% completed 19988 budget left",
  progress: 0.6,
  color: listColor[3],
);

ProjectModel projectModel4 = ProjectModel(
  job: "Flutter Development",
  name: "Hamza Chaouki",
  title: "90% completed 19988 budget left",
  progress: 0.9,
  color: listColor[4],
);

ProjectModel projectModel5 = ProjectModel(
  job: "Flutter Development",
  name: "Hamza El Hirch",
  title: "100% completed 19988 budget left",
  progress: 1,
  color: listColor[5],
);

ProjectModel projectModel6 = ProjectModel(
  job: "Web Dev",
  name: "Bilal Aboubi",
  title: "15% completed 19988 budget left",
  progress: 0.5,
  color: listColor[6],
);

ProjectModel projectModel7 = ProjectModel(
  job: "Marketing",
  name: "Mohammed Benmchich",
  title: "34% completed 19988 budget left",
  progress: 0.34,
  color: listColor[0],
);

ProjectModel projectModel8 = ProjectModel(
  job: "Illustration",
  name: "Mohammed Benmchich",
  title: "66% completed 19988 budget left",
  progress: 0.66,
  color: listColor[1],
);

ProjectModel projectModel9 = ProjectModel(
  job: "Editing",
  name: "Mohammed Benmchich",
  title: "77% completed 19988 budget left",
  progress: 0.77,
  color: listColor[2],
);

List<ProjectModel> listProjects = <ProjectModel>[
  projectModel0,
  projectModel1,
  projectModel2,
  projectModel3,
  projectModel4,
  projectModel5,
  projectModel6,
  projectModel7,
  projectModel8,
  projectModel9,
];

const List<Color> listColor = <Color>[
  Color(0xFFF56287),
  Color(0xFF37B34A),
  Color(0xFF1488CC),
  Color(0xFFE0B719),
  Color(0xffB455FF),
  Color(0xff07BBC7),
  Color(0xffFF5A5A),
];
